#
# spec file for package tali
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tali
Version:        40.9
Release:        2.4
Summary:        Yahtzee Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Other
URL:            https://live.gnome.org/Tali
Source0:        https://download.gnome.org/sources/tali/40/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12.0
BuildRequires:  pkgconfig(libgnome-games-support-1)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0

%description
Tali is like Yahtzee, or like poker with dice. The player rolls dice
to try to make the best possible combinations, like 4 of a kind, small
straight, and full house. The player is allowed 3 rolls per turn and
can hold certain dice with each roll.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/org.gnome.Tali.appdata.xml
%{_datadir}/applications/org.gnome.Tali.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Tali.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Tali*
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Tue Jul 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Drop obsolete update-desktop-files BuildRequires and macro.
* Sun Jan  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.9:
  + Updated translations.
* Sat Aug  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.8:
  + Updated translations.
* Tue Apr 26 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 40.7
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.6:
  + Update appdata screenshot hosting.
  + Fix flatpak build.
* Mon Jan 31 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.5:
  + Fix build with meson-0.61.
  + Updated translations.
* Sat Oct 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.4:
  + Updated translations.
* Sun Sep 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.3:
  + Updated translations.
* Tue Aug 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Updated translations.
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Updated translations.
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + No changes compared to 40.rc
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Updated translations.
* Sun Jan 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.3:
  + Updated translations.
* Mon Nov 23 2020 dimstar@opensuse.org
- Update to version 3.38.2:
  + Updated translations.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sun Sep  6 2020 Michael Gorse <mgorse@suse.com>
- Update to version 3.37.92:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Beta release
- Changes from version 3.37.3:
  + New application icon.
- Changes from version 3.37.1:
  + New dependency on libgnome-games-support.
  + Various code modernization.
  + Snap package updated to use gnome-3-34 extension.
  + Help updates.
  + Updated translations.
- Add pkgconfig(libgnome-games-support-1) BuildRequires: new
  dependency.
* Sat Jul  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Updated translations.
* Sat Mar 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Updated translations.
* Sat Mar  7 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updated translations.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Updated help.
  + Updated translations.
- Changes from version 3.35:
  + Fix Ctrl+Q keyboard shortcut for Quit.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Aug  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Help updates.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Add tests to validate AppStream metadata and .desktop file.
  + Consistently use org.gnome.Tali app id. Note that this renames
    the icons, .desktop, and AppStream metadata.
  + Miscellaneous cleanup.
- Add fdupes BuildRequires and macro, remove duplicates.
- Drop gtali and gtali-lang Obsoletes: No current openSUSE release
  have shipped those, so no longer needed.
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Switch from autotools to meson.
  + Stop using intltool.
  + Follow GNOME 3.32 app menu recommendations.
  + Update default AI names.
  + Add Keyboard Shortcuts overlay.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Drop intltool BuildRequires: No longer needed.
- Drop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un) macros,
  no longer needed.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Aug 15 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Added language headers to po files.
  + Updated translations.
* Mon Jul 18 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + No changes, version bump only.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Highres Icons added.
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Stop using deprecated gnome-common.
  + Fix RollDie() that could return 7.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Sep 15 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Reverted to old Docbook help.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Add symbolic icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Help updates.
  + Updated translations.
* Tue Dec  2 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + Remove GNOME Games branding.
  + Various Fixes.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Drop special permission handling, incl pwdutils Requires: this
  was required back when there was a system wide, shared highscore
  list.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Appdata fixes.
  + Added header bar for preferences.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Rename desktop file so tali appears in GNOME Software.
  + Change scores to be saved in ~/.local/share/tali.
  + Move undo move from the app menu to the header bar.
- Change %%suse_update_desktop_file gtali to
  %%suse_update_desktop_file tali following upstream changes.
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Use a GtkHeaderBar, pushed GTK requirement to 3.10, fixed
    layout issues.
  + Move scores from /var/games to home directory.
  + Updated translations.
- Remove calls to handle score files in /var/games.
- Drop gnome-games-scripts BuildRequires: no longer reuiqred, as
  we no longer have score files in /var/games.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Update website in about dialog.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + About dialog: use GtkLicense, remove period from sentence
    fragment.
  + Updated translations.
* Mon Nov 18 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Check for *-validate before using it, run autoupdate.
  + Fix scores.
  + Updated translations.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Appdata is now translatable.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix scores.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + No changes compared to 3.9.92.
* Mon Sep 23 2013 idonmez@suse.com
- Create games user/group on demand (fate#314560)
  + Depend on pwdutils for that to work.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add high contrast icons
  + Fix the missing user help
  + Add an appdata file
  + Fix sensitivity of undo move option
  + Updated translations.
- Add %%icon_theme_cache_post(un) scriptlets for the new
  HighContrast icons.
* Wed Aug 21 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Set prgname so WM_CLASS matches the desktop file.
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Renamed desktop file back to gtali.desktop.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
